#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = 'Pocheng, playma'
__email__ = 'pcghuang@gmail.com, scott820914@gmail.com'
__url__ = 'https://github.com/Envive/djangorestframework-camel-case'
__comapny__ = 'envive.tw'
__version__ = 'v2.0.1'
